From: antirez <antirez@gmail.com>
Date: Thu, 12 Nov 2009 10:21:26 +0000 (+0100)
Subject: LPOPPUSH renamed into RPOPLPUSH
X-Git-Url: https://git.saurik.com/redis.git/commitdiff_plain/0f5f7e9a82e24a875023af703a89a72d5c7fe411

LPOPPUSH renamed into RPOPLPUSH
---

diff --git a/redis-cli.c b/redis-cli.c
index c2d43a59..cc218a55 100644
--- a/redis-cli.c
+++ b/redis-cli.c
@@ -76,7 +76,7 @@ static struct redisCommand cmdTable[] = {
     {"lrange",4,REDIS_CMD_INLINE},
     {"ltrim",4,REDIS_CMD_INLINE},
     {"lrem",4,REDIS_CMD_BULK},
-    {"lpoppush",3,REDIS_CMD_BULK},
+    {"rpoplpush",3,REDIS_CMD_BULK},
     {"sadd",3,REDIS_CMD_BULK},
     {"srem",3,REDIS_CMD_BULK},
     {"smove",4,REDIS_CMD_BULK},
diff --git a/redis.c b/redis.c
index 90063525..aec09bdf 100644
--- a/redis.c
+++ b/redis.c
@@ -446,7 +446,7 @@ static void flushdbCommand(redisClient *c);
 static void flushallCommand(redisClient *c);
 static void sortCommand(redisClient *c);
 static void lremCommand(redisClient *c);
-static void lpoppushCommand(redisClient *c);
+static void rpoplpushcommand(redisClient *c);
 static void infoCommand(redisClient *c);
 static void mgetCommand(redisClient *c);
 static void monitorCommand(redisClient *c);
@@ -490,7 +490,7 @@ static struct redisCommand cmdTable[] = {
     {"lrange",lrangeCommand,4,REDIS_CMD_INLINE},
     {"ltrim",ltrimCommand,4,REDIS_CMD_INLINE},
     {"lrem",lremCommand,4,REDIS_CMD_BULK},
-    {"lpoppush",lpoppushCommand,3,REDIS_CMD_BULK},
+    {"rpoplpush",rpoplpushcommand,3,REDIS_CMD_BULK},
     {"sadd",saddCommand,3,REDIS_CMD_BULK|REDIS_CMD_DENYOOM},
     {"srem",sremCommand,3,REDIS_CMD_BULK},
     {"smove",smoveCommand,4,REDIS_CMD_BULK},
@@ -3473,7 +3473,7 @@ static void lremCommand(redisClient *c) {
 }
 
 /* This is the semantic of this command:
  *  LPOPPUSH srclist dstlist:
  *   IF LLEN(srclist) > 0
  *     element = RPOP srclist
  *     LPUSH dstlist element
@@ -3487,7 +3487,7 @@ static void lremCommand(redisClient *c) {
  * since the element is not just returned but pushed against another list
  * as well. This command was originally proposed by Ezra Zygmuntowicz.
  */
-static void lpoppushCommand(redisClient *c) {
+static void rpoplpushcommand(redisClient *c) {
     robj *sobj;
 
     sobj = lookupKeyWrite(c->db,c->argv[1]);
@@ -3473,7 +3473,7 @@ static void lremCommand(redisClient *c) {
 
 /* This is the semantic of this command:
- *  LPOPPUSH srclist dstlist:
+ *  RPOPLPUSH srclist dstlist:
  *   IF LLEN(srclist) > 0
  *     element = RPOP srclist